# iBoot —— AI模型服务化引擎

用于将Python程序封装成为Web互联网服务的Web服务化引擎（框架）。尤其适用于AI模型推理程序的互联网化封装和部署。

目前提供RESTful API、WebSocket和可视化Web GUI等多种形式的互联网API接口服务，支持二进制数据传输和文件上传。

## 开源主页 

- https://git.openi.org.cn/OpenI/cubeai_iboot

## 依赖包主页 

- https://pypi.org/project/iboot

## 依赖包安装

    $ pip install iboot -i https://pypi.tuna.tsinghua.edu.cn/simple

## 应用开发实例

- CubeAI智立方： https://git.openi.org.cn/OpenI/cubeai   
- CubeAI智立方模型实例（基于iBoot开发）： https://git.openi.org.cn/OpenI/cubeai_examples
